@@ -15,12 +15,15 @@ from localstack.constants import (
     DEFAULT_LAMBDA_CONTAINER_REGISTRY,
     DEFAULT_PORT_EDGE,
     DEFAULT_SERVICE_PORTS,
+    DEFAULT_VOLUME_DIR,
+    ENV_INTERNAL_TEST_COLLECT_METRIC,
     ENV_INTERNAL_TEST_RUN,
     FALSE_STRINGS,
-    INSTALL_DIR_INFRA,
     LOCALHOST,
     LOCALHOST_IP,
+    LOCALSTACK_ROOT_FOLDER,
     LOG_LEVELS,
+    MODULE_MAIN_PATH,
     TRACE_LOG_LEVELS,
     TRUE_STRINGS,
 )
@@ -61,15 +64,15 @@ class Directories:
 
     def __init__(
         self,
-        static_libs: str = None,
-        var_libs: str = None,
-        cache: str = None,
-        tmp: str = None,
-        functions: str = None,
-        data: str = None,
-        config: str = None,
-        init: str = None,
-        logs: str = None,
+        static_libs: str,
+        var_libs: str,
+        cache: str,
+        tmp: str,
+        functions: str,
+        data: str,
+        config: str,
+        init: str,
+        logs: str,
     ) -> None:
         super().__init__()
         self.static_libs = static_libs
@@ -83,10 +86,81 @@ class Directories:
         self.logs = logs
 
     @staticmethod
-    def from_config():
+    def defaults() -> "Directories":
+        """Returns Localstack directory paths based on the localstack filesystem hierarchy."""
+        return Directories(
+            static_libs="/usr/lib/localstack",
+            var_libs=f"{DEFAULT_VOLUME_DIR}/lib",
+            cache=f"{DEFAULT_VOLUME_DIR}/cache",
+            tmp=f"{DEFAULT_VOLUME_DIR}/tmp",
+            functions=f"{DEFAULT_VOLUME_DIR}/tmp",  # FIXME: remove - this was misconceived
+            data=f"{DEFAULT_VOLUME_DIR}/state",
+            logs=f"{DEFAULT_VOLUME_DIR}/logs",
+            config="/etc/localstack/conf.d",  # for future use
+            init="/etc/localstack/init",  # for future use
+        )
+
+    @staticmethod
+    def for_container() -> "Directories":
+        """
+        Returns Localstack directory paths as they are defined within the container. Everything shared and writable
+        lives in /var/lib/localstack or /tmp/localstack.
+
+        :returns: Directories object
+        """
+        defaults = Directories.defaults()
+
+        return Directories(
+            static_libs=defaults.static_libs,
+            var_libs=defaults.var_libs,
+            cache=defaults.cache,
+            tmp=defaults.tmp,
+            functions=defaults.functions,
+            data=defaults.data if PERSISTENCE else os.path.join(defaults.tmp, "state"),
+            config=defaults.config,
+            logs=defaults.logs,
+            init="/docker-entrypoint-initaws.d",  # FIXME should be reworked with lifecycle hooks
+        )
+
+    @staticmethod
+    def for_host() -> "Directories":
+        """Return directories used for running localstack in host mode. Note that these are *not* the directories
+        that are mounted into the container when the user starts localstack."""
+        root = os.environ.get("FILESYSTEM_ROOT") or os.path.join(
+            LOCALSTACK_ROOT_FOLDER, ".filesystem"
+        )
+        root = os.path.abspath(root)
+
+        defaults = Directories.for_container()
+
+        tmp = os.path.join(root, defaults.tmp.lstrip("/"))
+        data = os.path.join(root, defaults.data.lstrip("/"))
+
+        return Directories(
+            static_libs=os.path.join(root, defaults.static_libs.lstrip("/")),
+            var_libs=os.path.join(root, defaults.var_libs.lstrip("/")),
+            cache=os.path.join(root, defaults.cache.lstrip("/")),
+            tmp=tmp,
+            functions=os.path.join(root, defaults.functions.lstrip("/")),
+            data=data if PERSISTENCE else os.path.join(tmp, "state"),
+            config=os.path.join(root, defaults.config.lstrip("/")),
+            init=os.path.join(root, defaults.init.lstrip("/")),
+            logs=os.path.join(root, defaults.logs.lstrip("/")),
+        )
+
+    @staticmethod
+    def legacy_from_config():
         """Returns Localstack directory paths from the config/environment variables defined by the config."""
         # Note that the entries should be unique, as further downstream in docker_utils.py we're removing
         # duplicate host paths in the volume mounts via `dict(mount_volumes)`.
+
+        # legacy config variables inlined
+        INSTALL_DIR_INFRA = os.path.join(MODULE_MAIN_PATH, "infra")
+        # ephemeral cache dir that persists across reboots
+        CACHE_DIR = os.environ.get("CACHE_DIR", os.path.join(TMP_FOLDER, "cache")).strip()
+        # libs cache dir that persists across reboots
+        VAR_LIBS_DIR = os.environ.get("VAR_LIBS_DIR", os.path.join(TMP_FOLDER, "var_libs")).strip()
+
         return Directories(
             static_libs=INSTALL_DIR_INFRA,
             var_libs=VAR_LIBS_DIR,
@@ -100,7 +174,7 @@ class Directories:
         )
 
     @staticmethod
-    def for_container() -> "Directories":
+    def legacy_for_container() -> "Directories":
         """
         Returns Localstack directory paths as they are defined within the container. Everything shared and writable
         lives in /var/lib/localstack or /tmp/localstack.
@@ -110,10 +184,9 @@ class Directories:
         # only set CONTAINER_VAR_LIBS_FOLDER/CONTAINER_CACHE_FOLDER inside the container to redirect var_libs/cache to
         # another directory to avoid override by host mount
         var_libs = (
-            os.environ.get("CONTAINER_VAR_LIBS_FOLDER", "").strip()
-            or "/var/lib/localstack/var_libs"
+            os.environ.get("CONTAINER_VAR_LIBS_FOLDER", "").strip() or "/tmp/localstack/var_libs"
         )
-        cache = os.environ.get("CONTAINER_CACHE_FOLDER", "").strip() or "/var/lib/localstack/cache"
+        cache = os.environ.get("CONTAINER_CACHE_FOLDER", "").strip() or "/tmp/localstack/cache"
         tmp = (
             os.environ.get("CONTAINER_TMP_FOLDER", "").strip() or "/tmp/localstack"
         )  # TODO: discuss movement to /var/lib/localstack/tmp
@@ -121,14 +194,14 @@ class Directories:
             DATA_DIR if in_docker() else "/tmp/localstack_data"
         )  # TODO: move to /var/lib/localstack/data
         return Directories(
-            static_libs=INSTALL_DIR_INFRA,
+            static_libs=os.path.join(MODULE_MAIN_PATH, "infra"),
             var_libs=var_libs,
             cache=cache,
             tmp=tmp,
             functions=HOST_TMP_FOLDER,  # TODO: move to /var/lib/localstack/tmp
             data=data_dir,
             config=None,  # config directory is host-only
-            logs="/var/lib/localstack/logs",
+            logs="/tmp/localstack/logs",
             init="/docker-entrypoint-initaws.d",
         )
 
@@ -253,10 +326,10 @@ OVERRIDE_IN_DOCKER = is_env_true("OVERRIDE_IN_DOCKER")
 is_in_docker = in_docker()
 is_in_linux = is_linux()
 
-# the configuration profile to load
+# CLI specific: the configuration profile to load
 CONFIG_PROFILE = os.environ.get("CONFIG_PROFILE", "").strip()
 
-# host configuration directory
+# CLI specific: host configuration directory
 CONFIG_DIR = os.environ.get("CONFIG_DIR", os.path.expanduser("~/.localstack"))
 
 # keep this on top to populate environment
@@ -277,12 +350,21 @@ HOSTNAME_EXTERNAL = os.environ.get("HOSTNAME_EXTERNAL", "").strip() or LOCALHOST
 # name of the host under which the LocalStack services are available
 LOCALSTACK_HOSTNAME = os.environ.get("LOCALSTACK_HOSTNAME", "").strip() or LOCALHOST
 
-# directory for persisting data
+# directory for persisting data (TODO: deprecated, simply use PERSISTENCE=1)
 DATA_DIR = os.environ.get("DATA_DIR", "").strip()
 
+# whether localstack should persist service state across localstack runs
+PERSISTENCE = is_env_true("PERSISTENCE")
+
+# whether to clear config.dirs.tmp on startup and shutdown
+CLEAR_TMP_FOLDER = is_env_not_false("CLEAR_TMP_FOLDER")
+
 # folder for temporary files and data
 TMP_FOLDER = os.path.join(tempfile.gettempdir(), "localstack")
 
+# this is exclusively for the CLI to configure the container mount into /var/lib/localstack
+VOLUME_DIR = os.environ.get("LOCALSTACK_VOLUME_DIR", "").strip() or TMP_FOLDER
+
 # fix for Mac OS, to be able to mount /var/folders in Docker
 if TMP_FOLDER.startswith("/var/folders/") and os.path.exists("/private%s" % TMP_FOLDER):
     TMP_FOLDER = "/private%s" % TMP_FOLDER
@@ -290,10 +372,8 @@ if TMP_FOLDER.startswith("/var/folders/") and os.path.exists("/private%s" % TMP_
 # temporary folder of the host (required when running in Docker). Fall back to local tmp folder if not set
 HOST_TMP_FOLDER = os.environ.get("HOST_TMP_FOLDER", TMP_FOLDER)
 
-# ephemeral cache dir that persists across reboots
-CACHE_DIR = os.environ.get("CACHE_DIR", os.path.join(TMP_FOLDER, "cache")).strip()
-# libs cache dir that persists across reboots
-VAR_LIBS_DIR = os.environ.get("VAR_LIBS_DIR", os.path.join(TMP_FOLDER, "var_libs")).strip()
+# whether to use the old directory structure and mounting config
+LEGACY_DIRECTORIES = is_env_true("LEGACY_DIRECTORIES")
 
 # whether to enable verbose debug logging
 LS_LOG = eval_log_type("LS_LOG")
@@ -312,6 +392,12 @@ WAIT_FOR_DEBUGGER = is_env_true("WAIT_FOR_DEBUGGER")
 # TODO: this is deprecated and should be removed (edge port supports HTTP/HTTPS multiplexing)
 USE_SSL = is_env_true("USE_SSL")
 
+# whether to use the legacy edge proxy or the newer Gateway/HandlerChain framework
+LEGACY_EDGE_PROXY = is_env_true("LEGACY_EDGE_PROXY")
+
+# Whether to report internal failures as 500 or 501 errors.
+FAIL_FAST = is_env_true("FAIL_FAST")
+
 # whether to use the legacy single-region mode, defined via DEFAULT_REGION
 USE_SINGLE_REGION = is_env_true("USE_SINGLE_REGION")
 
@@ -353,6 +439,7 @@ DOCKER_BRIDGE_IP = os.environ.get("DOCKER_BRIDGE_IP", "").strip()
 ENABLE_CONFIG_UPDATES = is_env_true("ENABLE_CONFIG_UPDATES")
 
 # CORS settings
+DISABLE_CORS_HEADERS = is_env_true("DISABLE_CORS_HEADERS")
 DISABLE_CORS_CHECKS = is_env_true("DISABLE_CORS_CHECKS")
 DISABLE_CUSTOM_CORS_S3 = is_env_true("DISABLE_CUSTOM_CORS_S3")
 DISABLE_CUSTOM_CORS_APIGATEWAY = is_env_true("DISABLE_CUSTOM_CORS_APIGATEWAY")
@@ -367,15 +454,15 @@ DEBUG_ANALYTICS = is_env_true("DEBUG_ANALYTICS")
 # whether to eagerly start services
 EAGER_SERVICE_LOADING = is_env_true("EAGER_SERVICE_LOADING")
 
+# whether to enable multi-accounts
+MULTI_ACCOUNTS = is_env_true("MULTI_ACCOUNTS")
+
 # Whether to skip downloading additional infrastructure components (e.g., custom Elasticsearch versions)
 SKIP_INFRA_DOWNLOADS = os.environ.get("SKIP_INFRA_DOWNLOADS", "").strip()
 
 # Whether to skip downloading our signed SSL cert.
 SKIP_SSL_CERT_DOWNLOAD = is_env_true("SKIP_SSL_CERT_DOWNLOAD")
 
-# whether to enable legacy record&replay persistence mechanism (default true, but will be disabled in a future release!)
-LEGACY_PERSISTENCE = is_env_not_false("LEGACY_PERSISTENCE")
-
 # name of the main Docker container
 MAIN_CONTAINER_NAME = os.environ.get("MAIN_CONTAINER_NAME", "").strip() or "localstack_main"
 
@@ -438,7 +525,6 @@ try:
 except socket.error:
     pass
 
-
 # -----
 # SERVICE-SPECIFIC CONFIGS BELOW
 # -----
@@ -464,6 +550,9 @@ KINESIS_SHARD_LIMIT = os.environ.get("KINESIS_SHARD_LIMIT", "").strip() or "100"
 # delay in kinesalite response when making changes to streams
 KINESIS_LATENCY = os.environ.get("KINESIS_LATENCY", "").strip() or "500"
 
+# Delay between data persistence (in seconds)
+KINESIS_MOCK_PERSIST_INTERVAL = os.environ.get("KINESIS_MOCK_PERSIST_INTERVAL", "").strip() or "5s"
+
 # Kinesis provider - either "kinesis-mock" or "kinesalite"
 KINESIS_PROVIDER = os.environ.get("KINESIS_PROVIDER") or "kinesis-mock"
 
@@ -489,9 +578,18 @@ DYNAMODB_WRITE_ERROR_PROBABILITY = float(
 # JAVA EE heap size for dynamodb
 DYNAMODB_HEAP_SIZE = os.environ.get("DYNAMODB_HEAP_SIZE", "").strip() or "256m"
 
+# single DB instance across multiple credentials are regions
+DYNAMODB_SHARE_DB = int(os.environ.get("DYNAMODB_SHARE_DB") or 0)
+
+# Used to toggle QueueDeletedRecently errors when re-creating a queue within 60 seconds of deleting it
+SQS_DELAY_RECENTLY_DELETED = is_env_true("SQS_DELAY_RECENTLY_DELETED")
+
 # expose SQS on a specific port externally
 SQS_PORT_EXTERNAL = int(os.environ.get("SQS_PORT_EXTERNAL") or 0)
 
+# Strategy used when creating SQS queue urls. can be "off", "domain", or "path"
+SQS_ENDPOINT_STRATEGY = os.environ.get("SQS_ENDPOINT_STRATEGY", "") or "off"
+
 # host under which the LocalStack services are available from Lambda Docker containers
 HOSTNAME_FROM_LAMBDA = os.environ.get("HOSTNAME_FROM_LAMBDA", "").strip()
 
@@ -516,6 +614,9 @@ LAMBDA_DOCKER_DNS = os.environ.get("LAMBDA_DOCKER_DNS", "").strip()
 # additional flags passed to Lambda Docker run/create commands
 LAMBDA_DOCKER_FLAGS = os.environ.get("LAMBDA_DOCKER_FLAGS", "").strip()
 
+# prebuild images before execution? Increased cold start time on the tradeoff of increased time until lambda is ACTIVE
+LAMBDA_PREBUILD_IMAGES = is_env_true("LAMBDA_PREBUILD_IMAGES")
+
 # default container registry for lambda execution images
 LAMBDA_CONTAINER_REGISTRY = (
     os.environ.get("LAMBDA_CONTAINER_REGISTRY", "").strip() or DEFAULT_LAMBDA_CONTAINER_REGISTRY
@@ -537,10 +638,6 @@ WINDOWS_DOCKER_MOUNT_PREFIX = os.environ.get("WINDOWS_DOCKER_MOUNT_PREFIX", "/ho
 # whether to skip S3 presign URL signature validation (TODO: currently enabled, until all issues are resolved)
 S3_SKIP_SIGNATURE_VALIDATION = is_env_not_false("S3_SKIP_SIGNATURE_VALIDATION")
 
-# user ID of default user, to be returned on sts.get_caller_identity
-TEST_IAM_USER_ID = str(os.environ.get("TEST_IAM_USER_ID") or "").strip()
-TEST_IAM_USER_NAME = str(os.environ.get("TEST_IAM_USER_NAME") or "").strip()
-
 # user-defined lambda executor mode
 LAMBDA_EXECUTOR = os.environ.get("LAMBDA_EXECUTOR", "").strip()
 
@@ -603,12 +700,14 @@ CONFIG_ENV_VARS = [
     "DEVELOP",
     "DEVELOP_PORT",
     "DISABLE_CORS_CHECKS",
+    "DISABLE_CORS_HEADERS",
     "DISABLE_CUSTOM_CORS_APIGATEWAY",
     "DISABLE_CUSTOM_CORS_S3",
     "DISABLE_EVENTS",
     "DOCKER_BRIDGE_IP",
     "DYNAMODB_ERROR_PROBABILITY",
     "DYNAMODB_HEAP_SIZE",
+    "DYNAMODB_SHARE_DB",
     "DYNAMODB_READ_ERROR_PROBABILITY",
     "DYNAMODB_WRITE_ERROR_PROBABILITY",
     "EAGER_SERVICE_LOADING",
@@ -628,6 +727,7 @@ CONFIG_ENV_VARS = [
     "HOSTNAME_FROM_LAMBDA",
     "KINESIS_ERROR_PROBABILITY",
     "KINESIS_INITIALIZE_STREAMS",
+    "KINESIS_MOCK_PERSIST_INTERVAL",
     "LAMBDA_CODE_EXTRACT_TIME",
     "LAMBDA_CONTAINER_REGISTRY",
     "LAMBDA_DOCKER_DNS",
@@ -641,20 +741,26 @@ CONFIG_ENV_VARS = [
     "LAMBDA_REMOVE_CONTAINERS",
     "LAMBDA_STAY_OPEN_MODE",
     "LAMBDA_TRUNCATE_STDOUT",
+    "LEGACY_DIRECTORIES",
     "LEGACY_DOCKER_CLIENT",
+    "LEGACY_EDGE_PROXY",
     "LOCALSTACK_API_KEY",
     "LOCALSTACK_HOSTNAME",
     "LOG_LICENSE_ISSUES",
     "LS_LOG",
     "MAIN_CONTAINER_NAME",
+    "MULTI_ACCOUNTS",
+    "OPENSEARCH_ENDPOINT_STRATEGY",
     "OUTBOUND_HTTP_PROXY",
     "OUTBOUND_HTTPS_PROXY",
-    "PERSISTENCE_SINGLE_FILE",
+    "PERSISTENCE",
     "REQUESTS_CA_BUNDLE",
     "S3_SKIP_SIGNATURE_VALIDATION",
     "SERVICES",
     "SKIP_INFRA_DOWNLOADS",
     "SKIP_SSL_CERT_DOWNLOAD",
+    "SQS_DELAY_RECENTLY_DELETED",
+    "SQS_ENDPOINT_STRATEGY",
     "SQS_PORT_EXTERNAL",
     "STEPFUNCTIONS_LAMBDA_ENDPOINT",
     "SYNCHRONOUS_API_GATEWAY_EVENTS",
@@ -682,6 +788,11 @@ def is_local_test_mode() -> bool:
     return is_env_true(ENV_INTERNAL_TEST_RUN)
 
 
+def is_collect_metrics_mode() -> bool:
+    """Returns True if metric collection is enabled."""
+    return is_env_true(ENV_INTERNAL_TEST_COLLECT_METRIC)
+
+
 def collect_config_items() -> List[Tuple[str, Any]]:
     """Returns a list of key-value tuples of LocalStack configuration values."""
     none = object()  # sentinel object
@@ -704,10 +815,33 @@ def collect_config_items() -> List[Tuple[str, Any]]:
     return result
 
 
+def is_trace_logging_enabled():
+    if LS_LOG:
+        log_level = str(LS_LOG).upper()
+        return log_level.lower() in TRACE_LOG_LEVELS
+    return False
+
+
+# set log levels immediately, but will be overwritten later by setup_logging
+if DEBUG:
+    logging.getLogger("").setLevel(logging.DEBUG)
+    logging.getLogger("localstack").setLevel(logging.DEBUG)
+
+LOG = logging.getLogger(__name__)
+if is_trace_logging_enabled():
+    load_end_time = time.time()
+    LOG.debug(
+        "Initializing the configuration took %s ms", int((load_end_time - load_start_time) * 1000)
+    )
+
+
 def parse_service_ports() -> Dict[str, int]:
     """Parses the environment variable $SERVICES with a comma-separated list of services
     and (optional) ports they should run on: 'service1:port1,service2,service3:port3'"""
     service_ports = os.environ.get("SERVICES", "").strip()
+    if service_ports and not is_env_true("EAGER_SERVICE_LOADING"):
+        LOG.warning("SERVICES variable is ignored if EAGER_SERVICE_LOADING=0.")
+        service_ports = None  # TODO remove logic once we clear up the service ports stuff
     if not service_ports:
         return DEFAULT_SERVICE_PORTS
     result = {}
@@ -733,11 +867,6 @@ def parse_service_ports() -> Dict[str, int]:
     return result
 
 
-# TODO: leaving temporarily for patch compatibilty - remove!
-def populate_configs(service_ports=None):
-    pass
-
-
 # TODO: use functools cache, instead of global variable here
 SERVICE_PORTS = parse_service_ports()
 
@@ -815,19 +944,6 @@ def edge_ports_info():
     return result
 
 
-# set log levels
-if DEBUG:
-    logging.getLogger("").setLevel(logging.DEBUG)
-    logging.getLogger("localstack").setLevel(logging.DEBUG)
-
-if LS_LOG in TRACE_LOG_LEVELS:
-    load_end_time = time.time()
-    LOG = logging.getLogger(__name__)
-    LOG.debug(
-        "Initializing the configuration took %s ms", int((load_end_time - load_start_time) * 1000)
-    )
-
-
 class ServiceProviderConfig(Mapping[str, str]):
     _provider_config: Dict[str, str]
     default_value: str
@@ -875,18 +991,58 @@ SERVICE_PROVIDER_CONFIG = ServiceProviderConfig("default")
 
 SERVICE_PROVIDER_CONFIG.load_from_environment()
 
+
+def init_legacy_directories() -> Directories:
+    global PERSISTENCE
+    from localstack import constants
+
+    constants.DEFAULT_VOLUME_DIR = "/tmp/localstack"
+
+    if DATA_DIR:
+        PERSISTENCE = True
+
+    if is_in_docker:
+        dirs = Directories.legacy_for_container()
+    else:
+        dirs = Directories.legacy_from_config()
+
+    dirs.mkdirs()
+    return dirs
+
+
+def init_directories() -> Directories:
+    global DATA_DIR, PERSISTENCE
+
+    if DATA_DIR:
+        # deprecation path: DATA_DIR being set means persistence is activated, but we're ignoring the path set in
+        # DATA_DIR
+        os.environ["PERSISTENCE"] = "1"
+        PERSISTENCE = True
+
+    if is_in_docker:
+        dirs = Directories.for_container()
+    else:
+        dirs = Directories.for_host()
+
+    if PERSISTENCE:
+        if DATA_DIR:
+            LOG.warning(
+                "Persistence mode was activated using the DATA_DIR variable. DATA_DIR is deprecated and "
+                "its value is ignored. The data is instead stored into %s in the LocalStack volume.",
+                dirs.data,
+            )
+
+        # deprecation path
+        DATA_DIR = dirs.data
+        os.environ["DATA_DIR"] = dirs.data  # still needed for external tools
+
+    return dirs
+
+
 # initialize directories
-if is_in_docker:
-    dirs = Directories.for_container()
+dirs: Directories
+if LEGACY_DIRECTORIES:
+    CLEAR_TMP_FOLDER = False
+    dirs = init_legacy_directories()
 else:
-    dirs = Directories.from_config()
-
-dirs.mkdirs()
-
-# TODO: remove deprecation warning with next release
-for path in [dirs.config, os.path.join(dirs.tmp, ".localstack")]:
-    if path and os.path.isfile(path):
-        print(
-            f"warning: the config file .localstack is deprecated and no longer used, "
-            f"please remove it by running rm {path}"
-        )
+    dirs = init_directories()
