@@ -9,6 +9,7 @@ from typing import Dict, List
 
 import requests
 
+from localstack.aws.accounts import get_aws_account_id
 from localstack.aws.api import RequestContext
 from localstack.aws.api.firehose import (
     AmazonopensearchserviceDestinationConfiguration,
@@ -62,7 +63,6 @@ from localstack.aws.api.firehose import (
     UntagDeliveryStreamOutput,
     UpdateDestinationOutput,
 )
-from localstack.constants import TEST_AWS_ACCOUNT_ID
 from localstack.services.firehose.mappers import (
     convert_es_config_to_desc,
     convert_es_update_to_desc,
@@ -438,8 +438,7 @@ class FirehoseProvider(FirehoseApi):
         delivery_stream_description = region.delivery_streams.get(delivery_stream_name)
         if not delivery_stream_description:
             raise ResourceNotFoundException(
-                f"Firehose {delivery_stream_name} under account {TEST_AWS_ACCOUNT_ID} "
-                f"not found."
+                f"Firehose {delivery_stream_name} under account {get_aws_account_id()} not found."
             )
 
         # preprocess records, add any missing attributes
@@ -476,7 +475,10 @@ class FirehoseProvider(FirehoseApi):
                     unprocessed_records,
                 )
             if "S3DestinationDescription" in destination:
-                s3_dest_desc = destination["S3DestinationDescription"]
+                s3_dest_desc = (
+                    destination["S3DestinationDescription"]
+                    or destination["ExtendedS3DestinationDescription"]
+                )
                 self._put_records_to_s3_bucket(delivery_stream_name, records, s3_dest_desc)
             if "HttpEndpointDestinationDescription" in destination:
                 http_dest = destination["HttpEndpointDestinationDescription"]
