@@ -14,15 +14,22 @@ from moto.core import BaseModel
 from moto.core.base_backend import InstanceTrackerMeta
 
 from localstack import config, constants
+from localstack.aws.accounts import get_aws_account_id
 from localstack.constants import ENV_DEV, LOCALSTACK_INFRA_PROCESS, LOCALSTACK_VENV_FOLDER
 from localstack.runtime import events, hooks
 from localstack.services import generic_proxy, install, motoserver
 from localstack.services.generic_proxy import ProxyListener, start_proxy_server
 from localstack.services.plugins import SERVICE_PLUGINS, ServiceDisabled, wait_for_infra_shutdown
-from localstack.utils import analytics, config_listener, persistence
+from localstack.utils import analytics, config_listener, files, persistence
 from localstack.utils.analytics import event_publisher
 from localstack.utils.aws.request_context import patch_moto_request_handling
-from localstack.utils.bootstrap import canonicalize_api_names, in_ci, log_duration, setup_logging
+from localstack.utils.bootstrap import (
+    canonicalize_api_names,
+    in_ci,
+    is_api_enabled,
+    log_duration,
+    setup_logging,
+)
 from localstack.utils.container_networking import get_main_container_id
 from localstack.utils.files import cleanup_tmp_files
 from localstack.utils.net import get_free_tcp_port, is_port_open
@@ -63,7 +70,6 @@ SHUTDOWN_INFRA = threading.Event()
 # Start config update backdoor
 config_listener.start_listener()
 
-
 # ---------------
 # HELPER METHODS
 # ---------------
@@ -304,21 +310,25 @@ def cleanup_resources():
     cleanup_tmp_files()
     cleanup_threads_and_processes()
 
+    if config.CLEAR_TMP_FOLDER:
+        try:
+            files.rm_rf(config.dirs.tmp)
+        except PermissionError as e:
+            LOG.error(
+                "unable to delete temp folder %s: %s, please delete manually or you will keep seeing these errors",
+                config.dirs.tmp,
+                e,
+            )
+
 
 def log_startup_message(service):
     LOG.info("Starting mock %s service on %s ...", service, config.edge_ports_info())
 
 
 def check_aws_credentials():
-    session = boto3.Session()
-    credentials = None
-    # hardcode credentials here, to allow us to determine internal API calls made via boto3
-    os.environ["AWS_ACCESS_KEY_ID"] = constants.INTERNAL_AWS_ACCESS_KEY_ID
+    # Setup AWS environment vars, these are used by Boto when LocalStack makes internal cross-service calls
+    os.environ["AWS_ACCESS_KEY_ID"] = get_aws_account_id()
     os.environ["AWS_SECRET_ACCESS_KEY"] = constants.INTERNAL_AWS_SECRET_ACCESS_KEY
-    try:
-        credentials = session.get_credentials()
-    except Exception:
-        pass
     session = boto3.Session()
     credentials = session.get_credentials()
     assert credentials
@@ -373,6 +383,19 @@ def print_runtime_information(in_docker=False):
 
 
 def start_infra(asynchronous=False, apis=None):
+    if config.CLEAR_TMP_FOLDER:
+        # try to clear temp dir on startup
+        try:
+            files.rm_rf(config.dirs.tmp)
+        except PermissionError as e:
+            LOG.error(
+                "unable to delete temp folder %s: %s, please delete manually or you will keep seeing these errors",
+                config.dirs.tmp,
+                e,
+            )
+
+    config.dirs.mkdirs()
+
     events.infra_starting.set()
 
     try:
@@ -391,6 +414,7 @@ def start_infra(asynchronous=False, apis=None):
 
         # run hooks, to allow them to apply patches and changes
         hooks.on_infra_start.run()
+
         # with changes that hooks have made, now start the infrastructure
         thread = do_start_infra(asynchronous, apis, is_in_docker)
 
@@ -458,26 +482,19 @@ def do_start_infra(asynchronous, apis, is_in_docker):
         # listing the available service plugins will cause resolution of the entry points
         available_services = SERVICE_PLUGINS.list_available()
 
-        if persistence.is_persistence_enabled():
-            if not config.is_env_true(constants.ENV_PRO_ACTIVATED):
-                LOG.warning(
-                    "Persistence mechanism for community services (based on API calls record&replay) "
-                    "will be deprecated in versions 0.13.0 and above"
-                )
-
-            persistence.restore_persisted_data(available_services)
-
         # lazy is the default beginning with version 0.13.0
         if not config.EAGER_SERVICE_LOADING:
             return
 
         for api in available_services:
-            try:
-                SERVICE_PLUGINS.require(api)
-            except ServiceDisabled as e:
-                LOG.debug("%s", e)
-            except Exception:
-                LOG.exception("could not load service plugin %s", api)
+            # this should be the only call to is_api_enabled left
+            if is_api_enabled(api):
+                try:
+                    SERVICE_PLUGINS.require(api)
+                except ServiceDisabled as e:
+                    LOG.debug("%s", e)
+                except Exception:
+                    LOG.exception("could not load service plugin %s", api)
 
     @log_duration()
     def start_runtime_components():
@@ -504,7 +521,7 @@ def do_start_infra(asynchronous, apis, is_in_docker):
     thread = start_runtime_components()
     preload_services()
 
-    if config.dirs.data:
+    if config.PERSISTENCE:
         persistence.save_startup_info()
 
     print(READY_MARKER_OUTPUT)
